import socket

# Configure UDP socket
UDP_IP = "127.0.0.1"  # Use 127.0.0.1 instead of localhost
UDP_PORT = 9999       # Port specified in the Pure Data patch

# Create UDP socket
sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

# Set socket to reuse the port
sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)

try:
    # Bind the socket
    sock.bind((UDP_IP, UDP_PORT))
    print(f"Socket bind completed on {UDP_IP}:{UDP_PORT}. Waiting for messages...")

    while True:
        # Receive data
        data, addr = sock.recvfrom(1024)  # Buffer size 1024 bytes
        print(f"Raw data received from {addr}: {data}")  # Debug: print raw data
        try:
            # Decode the received message
            message = data.decode('utf-8').strip()
            print(f"Decoded message: {message}")  # Debug: print decoded message
            # Extract the value of z (expected: "z value;")
            if message.startswith("z "):
                z_value = message.split()[1].rstrip(';')
                print(f"Value of z: {z_value}")
            else:
                print("Message format not recognized")
        except UnicodeDecodeError:
            print("Decoding error: data not in text format")
except Exception as e:
    print(f"Error: {e}")
finally:
    print("Closing the socket...")
    sock.close()
